Benchmarks
---

*Dislcaimer: remember benchmarks are generally fraught with issues and their
legitimacy depends on a multitude of factors.*

I've used basic, but seemingly nice, [`pytest-benchmark`](https://pytest-benchmark.readthedocs.io/en/stable/usage.html)
to produce the following benchmarks on a fairly modern machine.

If you'd like to run these yourself, you'll need whatever according system 
dependency, if any, required by the specific algorithm as well as the Python
lib installed. Can install all via `pip install -r benchmark-requirements.txt`. 

The resulting output from benchmarks indicate what file and lib was used, (`cramjam` vs `gzip`)
`test_gzip[urls.10K-cramjam]` indicates `cramjam` and `benchmarks/data/urls.10K` file was used during the gzip benchmark.


Special performance notes:
---
In general, if the length of the output from de/compression is known, for any variant,  
you can provide `output_len=<<some int>>` to get a 1-4x performance increase. This
is allows us to avoid double allocation. 

Furthermore, you can provide `output_len` equal to the "at most" length when 
de/compressing `bytearray` objects; as these can be resized after the de/compression 
is finished and actual size is known for basically the same performance. This is not
true for `bytes` objects, as we cannot resize after de/compression and the result
will be trialing null bytes.

For snappy used in conjunction with `bytearray`s, this is only midly helpful as
we automatically estimate the buffer size and can resize the `bytearray` after.


--- 

#### Gzip

`make bench-gzip`


Notes
---
This benchmark is parameterized over setting `output_len=True/False` as an example
of the performance benefit that can be expected from various files/sizes.


```bash 
---------------------------------------------------------------------------------------------------------------------- benchmark: 48 tests ----------------------------------------------------------------------------------------------------------------------
Name (time in us)                                                              Min                    Max                   Mean                StdDev                 Median                   IQR            Outliers         OPS            Rounds  Iterations
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_gzip[Mark.Twain-Tom.Sawyer.txt-used-output_len=False-cramjam]        519.7970 (1.00)      1,039.8630 (1.10)        554.8131 (1.0)         57.9148 (1.11)        539.2260 (1.0)         35.0980 (1.0)       116;117  1,802.4088 (1.0)        1548           1
test_gzip[Mark.Twain-Tom.Sawyer.txt-used-output_len=False-gzip]           574.1360 (1.11)        949.8510 (1.00)        612.0804 (1.10)        53.3911 (1.02)        597.0000 (1.11)        40.9002 (1.17)      157;125  1,633.7722 (0.91)       1529           1
test_gzip[Mark.Twain-Tom.Sawyer.txt-used-output_len=True-cramjam]         518.2490 (1.0)       1,060.6960 (1.12)        557.3019 (1.00)        58.1539 (1.11)        540.5990 (1.00)        38.5972 (1.10)      173;161  1,794.3595 (1.00)       1733           1
test_gzip[Mark.Twain-Tom.Sawyer.txt-used-output_len=True-gzip]            573.6970 (1.11)        948.0410 (1.0)         610.1559 (1.10)        52.2425 (1.0)         595.9855 (1.11)        39.6890 (1.13)      137;112  1,638.9253 (0.91)       1402           1
test_gzip[alice29.txt-used-output_len=False-cramjam]                   11,126.7610 (21.47)    12,438.6120 (13.12)    11,511.1064 (20.75)      218.1752 (4.18)     11,467.2385 (21.27)      284.9400 (8.12)         19;2     86.8726 (0.05)         84           1
test_gzip[alice29.txt-used-output_len=False-gzip]                      11,987.2370 (23.13)    13,140.4910 (13.86)    12,407.8334 (22.36)      229.7621 (4.40)     12,373.9645 (22.95)      245.7390 (7.00)         25;3     80.5942 (0.04)         78           1
test_gzip[alice29.txt-used-output_len=True-cramjam]                    10,691.9930 (20.63)    12,840.6640 (13.54)    11,162.0962 (20.12)      263.0858 (5.04)     11,151.9600 (20.68)      216.9515 (6.18)         17;3     89.5889 (0.05)         85           1
test_gzip[alice29.txt-used-output_len=True-gzip]                       12,080.5280 (23.31)    14,159.6150 (14.94)    12,455.4363 (22.45)      258.2839 (4.94)     12,409.5640 (23.01)      197.6640 (5.63)         14;4     80.2862 (0.04)         80           1
test_gzip[asyoulik.txt-used-output_len=False-cramjam]                   8,554.8190 (16.51)    11,292.3600 (11.91)     8,928.3944 (16.09)      373.9090 (7.16)      8,848.9265 (16.41)      243.9890 (6.95)          4;4    112.0022 (0.06)        110           1
test_gzip[asyoulik.txt-used-output_len=False-gzip]                      9,105.9290 (17.57)    11,139.4500 (11.75)     9,525.5454 (17.17)      300.7739 (5.76)      9,455.9970 (17.54)      232.7680 (6.63)         14;5    104.9809 (0.06)        103           1
test_gzip[asyoulik.txt-used-output_len=True-cramjam]                    8,229.7350 (15.88)    10,414.6030 (10.99)     8,601.9106 (15.50)      305.7064 (5.85)      8,556.6525 (15.87)      263.3710 (7.50)         11;3    116.2532 (0.06)        116           1
test_gzip[asyoulik.txt-used-output_len=True-gzip]                       9,188.1850 (17.73)    11,324.9780 (11.95)     9,595.0928 (17.29)      296.8139 (5.68)      9,532.5355 (17.68)      308.6825 (8.79)         21;2    104.2199 (0.06)        104           1
test_gzip[fireworks.jpeg-used-output_len=False-cramjam]                 4,112.5220 (7.94)      4,831.0910 (5.10)      4,302.3705 (7.75)       135.0648 (2.59)      4,285.4420 (7.95)       177.0450 (5.04)         69;7    232.4300 (0.13)        233           1
test_gzip[fireworks.jpeg-used-output_len=False-gzip]                    3,199.6390 (6.17)      5,390.3660 (5.69)      3,390.9647 (6.11)       209.0182 (4.00)      3,358.5240 (6.23)       161.0110 (4.59)        19;14    294.9013 (0.16)        291           1
test_gzip[fireworks.jpeg-used-output_len=True-cramjam]                    949.3340 (1.83)      1,899.1360 (2.00)      1,005.6629 (1.81)        86.4962 (1.66)        986.2460 (1.83)        62.0280 (1.77)        72;50    994.3690 (0.55)       1031           1
test_gzip[fireworks.jpeg-used-output_len=True-gzip]                     3,200.2920 (6.18)      4,227.5530 (4.46)      3,387.2603 (6.11)       136.9476 (2.62)      3,354.4090 (6.22)       182.4480 (5.20)         77;4    295.2238 (0.16)        291           1
test_gzip[geo.protodata-used-output_len=False-cramjam]                  1,738.4310 (3.35)      2,604.3500 (2.75)      1,849.7277 (3.33)       106.3325 (2.04)      1,827.7090 (3.39)        90.1718 (2.57)        62;33    540.6201 (0.30)        555           1
test_gzip[geo.protodata-used-output_len=False-gzip]                     2,147.9430 (4.14)      2,577.6970 (2.72)      2,257.4456 (4.07)        84.2493 (1.61)      2,242.1480 (4.16)        99.5392 (2.84)       114;18    442.9786 (0.25)        453           1
test_gzip[geo.protodata-used-output_len=True-cramjam]                   1,725.6690 (3.33)      2,718.6700 (2.87)      1,836.1617 (3.31)        89.9981 (1.72)      1,815.8690 (3.37)        85.5890 (2.44)       101;31    544.6144 (0.30)        510           1
test_gzip[geo.protodata-used-output_len=True-gzip]                      2,127.9530 (4.11)      3,138.8670 (3.31)      2,272.0031 (4.10)       122.4131 (2.34)      2,247.9540 (4.17)       115.8465 (3.30)        47;18    440.1402 (0.24)        429           1
test_gzip[html-used-output_len=False-cramjam]                           2,104.5090 (4.06)      3,175.1630 (3.35)      2,225.5431 (4.01)       115.0906 (2.20)      2,201.1520 (4.08)       104.5572 (2.98)        53;20    449.3285 (0.25)        443           1
test_gzip[html-used-output_len=False-gzip]                              2,500.7590 (4.83)      3,616.7810 (3.82)      2,641.0550 (4.76)       123.6254 (2.37)      2,620.8410 (4.86)       111.6068 (3.18)        56;20    378.6366 (0.21)        359           1
test_gzip[html-used-output_len=True-cramjam]                            2,079.2420 (4.01)      3,400.4040 (3.59)      2,222.3146 (4.01)       138.7664 (2.66)      2,188.7960 (4.06)       103.3685 (2.95)        44;30    449.9813 (0.25)        453           1
test_gzip[html-used-output_len=True-gzip]                               2,478.4130 (4.78)      3,809.0550 (4.02)      2,638.6508 (4.76)       126.2851 (2.42)      2,616.6670 (4.85)       128.5782 (3.66)         50;9    378.9816 (0.21)        333           1
test_gzip[html_x_4-used-output_len=False-cramjam]                      10,130.5030 (19.55)    11,372.8290 (12.00)    10,590.8331 (19.09)      273.9986 (5.24)     10,554.1310 (19.57)      426.2085 (12.14)        26;0     94.4213 (0.05)         91           1
test_gzip[html_x_4-used-output_len=False-gzip]                         11,047.6520 (21.32)    14,428.7200 (15.22)    11,484.8105 (20.70)      479.1162 (9.17)     11,389.2690 (21.12)      283.3758 (8.07)          5;5     87.0715 (0.05)         89           1
test_gzip[html_x_4-used-output_len=True-cramjam]                        9,458.3850 (18.25)    11,396.0560 (12.02)     9,943.5637 (17.92)      322.5896 (6.17)      9,892.4310 (18.35)      408.9162 (11.65)        28;3    100.5676 (0.06)        101           1
test_gzip[html_x_4-used-output_len=True-gzip]                          10,967.9200 (21.16)    12,620.0610 (13.31)    11,653.9219 (21.01)      420.0944 (8.04)     11,559.7885 (21.44)      674.0520 (19.20)        24;0     85.8080 (0.05)         76           1
test_gzip[kppkn.gtb-used-output_len=False-cramjam]                     40,256.6710 (77.68)    43,371.8420 (45.75)    41,135.3838 (74.14)      763.5835 (14.62)    41,052.4730 (76.13)      553.2935 (15.76)         4;3     24.3100 (0.01)         25           1
test_gzip[kppkn.gtb-used-output_len=False-gzip]                        64,079.5300 (123.65)   66,277.4240 (69.91)    64,924.9089 (117.02)     565.3003 (10.82)    64,802.9350 (120.18)     815.0115 (23.22)         3;0     15.4024 (0.01)         16           1
test_gzip[kppkn.gtb-used-output_len=True-cramjam]                      40,419.5090 (77.99)    47,952.8860 (50.58)    42,200.0288 (76.06)    1,794.2808 (34.35)    41,631.6520 (77.21)    2,457.0025 (70.00)         3;1     23.6967 (0.01)         24           1
test_gzip[kppkn.gtb-used-output_len=True-gzip]                         64,210.5460 (123.90)   66,613.3220 (70.26)    65,246.4269 (117.60)     741.0967 (14.19)    65,081.6270 (120.69)   1,015.2845 (28.93)         6;0     15.3265 (0.01)         16           1
test_gzip[lcet10.txt-used-output_len=False-cramjam]                    27,573.1010 (53.20)    34,978.2250 (36.90)    29,197.9029 (52.63)    1,652.9253 (31.64)    28,802.4685 (53.41)      736.2490 (20.98)         3;3     34.2490 (0.02)         36           1
test_gzip[lcet10.txt-used-output_len=False-gzip]                       30,280.9470 (58.43)    32,562.8860 (34.35)    31,243.7204 (56.31)      571.5751 (10.94)    31,290.7620 (58.03)      880.7153 (25.09)        12;0     32.0064 (0.02)         33           1
test_gzip[lcet10.txt-used-output_len=True-cramjam]                      9,555.1300 (18.44)    10,782.8600 (11.37)     9,912.5000 (17.87)      228.0582 (4.37)      9,872.4590 (18.31)      251.0783 (7.15)         26;4    100.8827 (0.06)        101           1
test_gzip[lcet10.txt-used-output_len=True-gzip]                        29,901.7910 (57.70)    32,865.9390 (34.67)    30,719.4480 (55.37)      747.3969 (14.31)    30,474.8960 (56.52)      705.1667 (20.09)         4;3     32.5527 (0.02)         33           1
test_gzip[paper-100k.pdf-used-output_len=False-cramjam]                 2,967.7560 (5.73)      4,924.8240 (5.19)      3,123.3734 (5.63)       150.6200 (2.88)      3,098.6220 (5.75)       129.4330 (3.69)        28;14    320.1667 (0.18)        317           1
test_gzip[paper-100k.pdf-used-output_len=False-gzip]                    3,213.1740 (6.20)      4,502.4180 (4.75)      3,398.0615 (6.12)       153.2343 (2.93)      3,375.8890 (6.26)       153.5790 (4.38)        51;12    294.2854 (0.16)        286           1
test_gzip[paper-100k.pdf-used-output_len=True-cramjam]                  2,516.1480 (4.86)      3,818.5730 (4.03)      2,644.5456 (4.77)       114.8152 (2.20)      2,623.0940 (4.86)       130.8360 (3.73)         69;8    378.1368 (0.21)        346           1
test_gzip[paper-100k.pdf-used-output_len=True-gzip]                     3,219.8630 (6.21)      4,964.1200 (5.24)      3,397.6387 (6.12)       181.2687 (3.47)      3,368.3955 (6.25)       150.5255 (4.29)        25;11    294.3221 (0.16)        280           1
test_gzip[plrabn12.txt-used-output_len=False-cramjam]                  49,762.2040 (96.02)    52,859.5690 (55.76)    50,738.7668 (91.45)      738.6969 (14.14)    50,563.2525 (93.77)      699.4550 (19.93)         4;2     19.7088 (0.01)         20           1
test_gzip[plrabn12.txt-used-output_len=False-gzip]                     53,138.4560 (102.53)   57,021.3700 (60.15)    54,463.9891 (98.17)      935.8547 (17.91)    54,264.2380 (100.63)   1,299.5680 (37.03)         5;0     18.3608 (0.01)         19           1
test_gzip[plrabn12.txt-used-output_len=True-cramjam]                   11,388.8090 (21.98)    15,003.8590 (15.83)    11,920.0316 (21.48)      539.3715 (10.32)    11,808.2690 (21.90)      325.8090 (9.28)          7;7     83.8924 (0.05)         83           1
test_gzip[plrabn12.txt-used-output_len=True-gzip]                      53,538.2260 (103.31)   56,180.2010 (59.26)    54,724.8323 (98.64)      721.1164 (13.80)    54,695.3400 (101.43)     949.2280 (27.05)         7;0     18.2732 (0.01)         19           1
test_gzip[urls.10K-used-output_len=False-cramjam]                      38,097.4640 (73.51)    45,489.4830 (47.98)    39,572.1519 (71.33)    1,431.1925 (27.40)    39,344.5560 (72.96)    1,227.8805 (34.98)         2;1     25.2703 (0.01)         24           1
test_gzip[urls.10K-used-output_len=False-gzip]                         41,281.0130 (79.65)    43,838.5800 (46.24)    42,369.0851 (76.37)      765.5144 (14.65)    42,351.6570 (78.54)    1,138.2070 (32.43)         9;0     23.6021 (0.01)         23           1
test_gzip[urls.10K-used-output_len=True-cramjam]                        7,313.0000 (14.11)     9,913.0270 (10.46)     7,718.4330 (13.91)      313.5716 (6.00)      7,633.9700 (14.16)      345.0630 (9.83)         17;5    129.5600 (0.07)        130           1
test_gzip[urls.10K-used-output_len=True-gzip]                          41,650.3010 (80.37)    44,860.9970 (47.32)    42,876.6647 (77.28)      703.7033 (13.47)    42,893.8560 (79.55)      851.1110 (24.25)         6;1     23.3227 (0.01)         24           1
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

```

#### Snappy

`make bench-snappy`

```bash
-------------------------------------------------------------------------------------------------------- benchmark: 24 tests ---------------------------------------------------------------------------------------------------------
Name (time in us)                                         Min                   Max                  Mean              StdDev                Median                 IQR            Outliers          OPS            Rounds  Iterations
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_snappy[Mark.Twain-Tom.Sawyer.txt-cramjam]        68.0490 (4.44)       236.4670 (3.23)        74.1624 (4.38)      12.2258 (2.78)        70.6645 (4.42)       3.8065 (6.30)      393;654  13,483.9307 (0.23)       4220           1
test_snappy[Mark.Twain-Tom.Sawyer.txt-snappy]         52.8250 (3.45)       209.7710 (2.86)        57.8734 (3.42)      10.0498 (2.29)        55.1665 (3.45)       2.0325 (3.37)    1153;1990  17,279.1036 (0.29)      13972           1
test_snappy[alice29.txt-cramjam]                     296.4050 (19.34)      513.2750 (7.00)       319.8824 (18.88)     26.2029 (5.96)       314.6850 (19.70)     20.1032 (33.30)     257;192   3,126.1485 (0.05)       2463           1
test_snappy[alice29.txt-snappy]                      601.3360 (39.24)      896.2440 (12.23)      642.0986 (37.90)     43.3138 (9.85)       637.0050 (39.87)     44.1420 (73.11)     176;101   1,557.3933 (0.03)       1583           1
test_snappy[asyoulik.txt-cramjam]                    314.2370 (20.51)      638.6460 (8.72)       337.8341 (19.94)     34.3076 (7.80)       325.6750 (20.38)     22.5742 (37.39)     273;269   2,960.0329 (0.05)       2917           1
test_snappy[asyoulik.txt-snappy]                     532.4610 (34.75)      881.1000 (12.02)      567.8900 (33.52)     43.3191 (9.85)       555.2595 (34.75)     41.0570 (68.00)     214;144   1,760.9043 (0.03)       1830           1
test_snappy[fireworks.jpeg-cramjam]                   41.9580 (2.74)       401.9790 (5.49)        46.1660 (2.73)       9.2259 (2.10)        44.0280 (2.76)       2.2282 (3.69)    1134;2184  21,660.9429 (0.37)      16493           1
test_snappy[fireworks.jpeg-snappy]                    15.3240 (1.0)        125.1180 (1.71)        16.9414 (1.0)        4.3968 (1.0)         15.9770 (1.0)        0.6038 (1.0)     1364;1766  59,027.0559 (1.0)       21891           1
test_snappy[geo.protodata-cramjam]                   109.6360 (7.15)       224.8130 (3.07)       119.6756 (7.06)      13.9476 (3.17)       114.2810 (7.15)       7.8245 (12.96)     765;871   8,355.9254 (0.14)       6107           1
test_snappy[geo.protodata-snappy]                    142.9090 (9.33)       335.9500 (4.58)       157.0690 (9.27)      18.1315 (4.12)       150.7170 (9.43)      10.6040 (17.56)     789;833   6,366.6276 (0.11)       5992           1
test_snappy[html-cramjam]                            148.6780 (9.70)       305.4290 (4.17)       159.0390 (9.39)      15.5382 (3.53)       154.0180 (9.64)       9.1190 (15.10)     702;779   6,287.7660 (0.11)       5853           1
test_snappy[html-snappy]                             156.2010 (10.19)      305.7490 (4.17)       168.3579 (9.94)      17.6330 (4.01)       161.9390 (10.14)     10.3047 (17.07)     563;600   5,939.7280 (0.10)       4239           1
test_snappy[html_x_4-cramjam]                        159.5320 (10.41)      504.7690 (6.89)       168.8123 (9.96)      18.3322 (4.17)       160.9430 (10.07)      9.5325 (15.79)     254;297   5,923.7385 (0.10)       2973           1
test_snappy[html_x_4-snappy]                         633.7830 (41.36)    1,055.7020 (14.41)      683.7402 (40.36)     56.0549 (12.75)      667.5120 (41.78)     45.0975 (74.70)     180;105   1,462.5438 (0.02)       1408           1
test_snappy[kppkn.gtb-cramjam]                       205.8880 (13.44)      391.8670 (5.35)       219.9534 (12.98)     21.6411 (4.92)       212.6530 (13.31)     14.3255 (23.73)     316;301   4,546.4180 (0.08)       2705           1
test_snappy[kppkn.gtb-snappy]                        504.1990 (32.90)      879.5870 (12.00)      546.0574 (32.23)     51.4486 (11.70)      531.9175 (33.29)     42.8270 (70.93)     237;198   1,831.3095 (0.03)       1774           1
test_snappy[lcet10.txt-cramjam]                      286.5250 (18.70)      559.8080 (7.64)       311.1426 (18.37)     33.3866 (7.59)       297.2815 (18.61)     28.1930 (46.70)     356;283   3,213.9606 (0.05)       3010           1
test_snappy[lcet10.txt-snappy]                     1,591.0940 (103.83)   2,195.9160 (29.97)    1,711.3473 (101.02)   106.9863 (24.33)    1,676.0640 (104.90)   107.2650 (177.66)     126;32     584.3349 (0.01)        586           1
test_snappy[paper-100k.pdf-cramjam]                   48.8270 (3.19)       107.3140 (1.46)        53.8996 (3.18)       7.4700 (1.70)        50.9340 (3.19)       3.0750 (5.09)    1894;2399  18,553.0061 (0.31)      12112           1
test_snappy[paper-100k.pdf-snappy]                    19.9350 (1.30)        73.2760 (1.0)         22.8507 (1.35)       4.4256 (1.01)        21.3490 (1.34)       1.7780 (2.94)    4126;4357  43,762.4046 (0.74)      26118           1
test_snappy[plrabn12.txt-cramjam]                    524.0590 (34.20)      988.9050 (13.50)      558.4253 (32.96)     50.0324 (11.38)      542.4060 (33.95)     38.8713 (64.38)     171;133   1,790.7497 (0.03)       1629           1
test_snappy[plrabn12.txt-snappy]                   2,316.0010 (151.14)   3,066.4880 (41.85)    2,449.0969 (144.56)   122.0491 (27.76)    2,421.2130 (151.54)   113.4473 (187.90)      74;30     408.3138 (0.01)        401           1
test_snappy[urls.10K-cramjam]                        480.5240 (31.36)      960.4570 (13.11)      516.9837 (30.52)     53.2631 (12.11)      497.5085 (31.14)     38.3690 (63.55)     178;165   1,934.2969 (0.03)       1622           1
test_snappy[urls.10K-snappy]                       1,934.9160 (126.27)   2,981.1910 (40.68)    2,050.5994 (121.04)   125.9153 (28.64)    2,022.6760 (126.60)   100.3135 (166.15)      48;29     487.6623 (0.01)        501           1
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
```

##### Benchmarks for using `compress_into` and `decompress_into`
All variants except `lz4` for now, implement a `compress_into` and `decompress_into`
This is where, if you have a Python numpy array pre-allocated to the size of the
de/compress data output, we can place the bytes directly into that buffer.

Again, since basically no variants implement similar functionality as we saw in the Gzip `output_len`
benchmarks, this benchmark is specific to `cramjam`

```bash
-------------------------------------------------------------------------------------------------------------------- benchmark: 24 tests ---------------------------------------------------------------------------------------------------------------------
Name (time in us)                                                                        Min                 Max                Mean             StdDev              Median                IQR            Outliers  OPS (Kops/s)            Rounds  Iterations
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_cramjam_snappy_de_compress_into[Mark.Twain-Tom.Sawyer.txt-compress_into]        41.7650 (2.38)     104.0260 (1.76)      46.2884 (2.42)      6.5739 (2.29)      43.9400 (2.39)      1.6860 (4.70)    2130;2781       21.6037 (0.41)      17246           1
test_cramjam_snappy_de_compress_into[Mark.Twain-Tom.Sawyer.txt-decompress_into]      21.3400 (1.22)      61.8010 (1.04)      23.0667 (1.21)      3.2925 (1.14)      22.2090 (1.21)      0.3585 (1.0)      974;2318       43.3526 (0.83)      13000           1
test_cramjam_snappy_de_compress_into[alice29.txt-compress_into]                     205.7540 (11.72)    510.2070 (8.62)     223.4270 (11.67)    20.4450 (7.11)     214.1430 (11.66)    14.0580 (39.21)     557;474        4.4757 (0.09)       4574           1
test_cramjam_snappy_de_compress_into[alice29.txt-decompress_into]                    83.6290 (4.76)     216.7800 (3.66)      91.1061 (4.76)     12.1865 (4.24)      86.5520 (4.71)      2.8550 (7.96)     880;1660       10.9762 (0.21)       8572           1
test_cramjam_snappy_de_compress_into[asyoulik.txt-compress_into]                    220.0860 (12.54)    616.0500 (10.41)    241.1679 (12.60)    25.5963 (8.90)     229.8620 (12.52)    16.8125 (46.89)     394;349        4.1465 (0.08)       3348           1
test_cramjam_snappy_de_compress_into[asyoulik.txt-decompress_into]                   87.8920 (5.01)     178.8330 (3.02)      95.8756 (5.01)     11.5868 (4.03)      91.4080 (4.98)      3.2860 (9.17)     949;1703       10.4302 (0.20)       8875           1
test_cramjam_snappy_de_compress_into[fireworks.jpeg-compress_into]                   25.6260 (1.46)      63.8190 (1.08)      27.7547 (1.45)      3.7059 (1.29)      26.6040 (1.45)      0.7890 (2.20)    2774;3234       36.0300 (0.69)      28518           1
test_cramjam_snappy_de_compress_into[fireworks.jpeg-decompress_into]                 17.5530 (1.0)       59.1750 (1.0)       19.1416 (1.0)       2.8766 (1.0)       18.3660 (1.0)       0.4600 (1.28)    3385;4030       52.2422 (1.0)       41681           1
test_cramjam_snappy_de_compress_into[geo.protodata-compress_into]                    62.9040 (3.58)     139.3470 (2.35)      68.9734 (3.60)      8.2557 (2.87)      65.8000 (3.58)      2.5645 (7.15)    1312;2267       14.4983 (0.28)      12772           1
test_cramjam_snappy_de_compress_into[geo.protodata-decompress_into]                  35.1860 (2.00)      82.0800 (1.39)      38.0429 (1.99)      4.8740 (1.69)      36.5620 (1.99)      1.1445 (3.19)    2212;2524       26.2861 (0.50)      20812           1
test_cramjam_snappy_de_compress_into[html-compress_into]                             93.2700 (5.31)     192.9050 (3.26)     101.1416 (5.28)     10.3539 (3.60)      97.0850 (5.29)      3.9940 (11.14)   1048;1560        9.8871 (0.19)       9303           1
test_cramjam_snappy_de_compress_into[html-decompress_into]                           45.6410 (2.60)     109.9500 (1.86)      49.4838 (2.59)      5.8214 (2.02)      47.5050 (2.59)      1.6060 (4.48)    2094;2462       20.2087 (0.39)      17202           1
test_cramjam_snappy_de_compress_into[html_x_4-compress_into]                         92.9150 (5.29)     198.6570 (3.36)     101.2886 (5.29)     11.0534 (3.84)      96.9960 (5.28)      3.7150 (10.36)   1016;1618        9.8728 (0.19)       9170           1
test_cramjam_snappy_de_compress_into[html_x_4-decompress_into]                       45.4800 (2.59)     118.9590 (2.01)      49.8765 (2.61)      6.6306 (2.31)      47.4450 (2.58)      1.5590 (4.35)    2276;2776       20.0495 (0.38)      17336           1
test_cramjam_snappy_de_compress_into[kppkn.gtb-compress_into]                       127.1530 (7.24)     223.4660 (3.78)     137.4548 (7.18)     12.9390 (4.50)     131.7830 (7.18)      7.1705 (20.00)     844;886        7.2751 (0.14)       6095           1
test_cramjam_snappy_de_compress_into[kppkn.gtb-decompress_into]                      69.3210 (3.95)     162.5740 (2.75)      76.7793 (4.01)     10.2444 (3.56)      73.8570 (4.02)      2.7220 (7.59)    1118;2146       13.0243 (0.25)      11894           1
test_cramjam_snappy_de_compress_into[lcet10.txt-compress_into]                      191.7940 (10.93)    338.6870 (5.72)     207.6322 (10.85)    18.0247 (6.27)     199.7430 (10.88)    11.4570 (31.96)     587;531        4.8162 (0.09)       5000           1
test_cramjam_snappy_de_compress_into[lcet10.txt-decompress_into]                     77.7750 (4.43)     338.1339 (5.71)      84.4765 (4.41)     10.4472 (3.63)      80.7050 (4.39)      2.7620 (7.70)     984;2034       11.8376 (0.23)      10322           1
test_cramjam_snappy_de_compress_into[paper-100k.pdf-compress_into]                   26.6640 (1.52)     242.2140 (4.09)      29.3447 (1.53)      4.2104 (1.46)      28.1900 (1.53)      0.9080 (2.53)    2437;2960       34.0777 (0.65)      26911           1
test_cramjam_snappy_de_compress_into[paper-100k.pdf-decompress_into]                 21.8910 (1.25)     244.9150 (4.14)      23.8577 (1.25)      3.6118 (1.26)      22.8060 (1.24)      0.8357 (2.33)    2815;3565       41.9152 (0.80)      30571           1
test_cramjam_snappy_de_compress_into[plrabn12.txt-compress_into]                    232.9760 (13.27)    423.5980 (7.16)     252.4664 (13.19)    22.3262 (7.76)     242.1575 (13.19)    16.2451 (45.31)     452;341        3.9609 (0.08)       3832           1
test_cramjam_snappy_de_compress_into[plrabn12.txt-decompress_into]                   93.4720 (5.33)     191.9320 (3.24)     100.7861 (5.27)     10.8995 (3.79)      96.8360 (5.27)      3.2852 (9.16)     680;1188        9.9220 (0.19)       6673           1
test_cramjam_snappy_de_compress_into[urls.10K-compress_into]                        140.6160 (8.01)     267.2590 (4.52)     152.2335 (7.95)     14.4990 (5.04)     146.4630 (7.97)      6.3553 (17.73)     682;938        6.5689 (0.13)       5901           1
test_cramjam_snappy_de_compress_into[urls.10K-decompress_into]                       58.6630 (3.34)     126.4510 (2.14)      63.6568 (3.33)      7.5369 (2.62)      60.9710 (3.32)      1.9845 (5.54)    1022;1536       15.7092 (0.30)       9257           1
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
```

#### Lz4

`make bench-lz4`

```bash
------------------------------------------------------------------------------------------------------------ benchmark: 24 tests ------------------------------------------------------------------------------------------------------------
Name (time in us)                                          Min                    Max                   Mean                StdDev                 Median                   IQR            Outliers         OPS            Rounds  Iterations
---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_lz4[Mark.Twain-Tom.Sawyer.txt-cramjam]           205.9030 (1.0)         487.6750 (1.16)        235.1050 (1.0)         42.5729 (1.46)        218.6220 (1.0)         21.7648 (1.13)      482;537  4,253.4186 (1.0)        3949           1
test_lz4[Mark.Twain-Tom.Sawyer.txt-python-lz4]        211.8470 (1.03)        421.1400 (1.0)         258.1943 (1.10)        61.8064 (2.11)        223.0840 (1.02)        60.6820 (3.16)      453;175  3,873.0528 (0.91)       1935           1
test_lz4[alice29.txt-cramjam]                       1,829.0490 (8.88)      2,390.3910 (5.68)      1,939.9762 (8.25)       101.4219 (3.47)      1,913.4190 (8.75)        93.0095 (4.84)       103;34    515.4702 (0.12)        501           1
test_lz4[alice29.txt-python-lz4]                    3,035.4070 (14.74)     3,972.2100 (9.43)      3,263.6920 (13.88)      156.1966 (5.34)      3,215.2680 (14.71)      166.8995 (8.68)        73;16    306.4015 (0.07)        309           1
test_lz4[asyoulik.txt-cramjam]                      1,440.7250 (7.00)      2,176.8530 (5.17)      1,530.6210 (6.51)        86.4176 (2.95)      1,508.6560 (6.90)        75.1295 (3.91)       133;45    653.3296 (0.15)        604           1
test_lz4[asyoulik.txt-python-lz4]                   2,627.0850 (12.76)     4,329.6350 (10.28)     2,802.7557 (11.92)      209.5091 (7.16)      2,757.2175 (12.61)      113.6400 (5.91)        24;26    356.7917 (0.08)        322           1
test_lz4[fireworks.jpeg-cramjam]                      298.4680 (1.45)        534.6860 (1.27)        321.2755 (1.37)        29.2533 (1.0)         307.8030 (1.41)        19.2315 (1.0)       214;195  3,112.5937 (0.73)       1987           1
test_lz4[fireworks.jpeg-python-lz4]                 2,646.1140 (12.85)     3,782.5490 (8.98)      2,811.4612 (11.96)      141.2595 (4.83)      2,785.4975 (12.74)      133.7265 (6.95)         25;9    355.6869 (0.08)        204           1
test_lz4[geo.protodata-cramjam]                       488.7870 (2.37)        840.0170 (1.99)        522.8667 (2.22)        49.3122 (1.69)        508.8640 (2.33)        35.3760 (1.84)      169;150  1,912.5334 (0.45)       1686           1
test_lz4[geo.protodata-python-lz4]                    671.5480 (3.26)      1,211.8090 (2.88)        719.1932 (3.06)        47.4541 (1.62)        706.5320 (3.23)        35.7863 (1.86)       115;89  1,390.4469 (0.33)       1137           1
test_lz4[html-cramjam]                                508.0540 (2.47)        870.8210 (2.07)        556.4302 (2.37)        55.0444 (1.88)        539.5200 (2.47)        40.0038 (2.08)      162;130  1,797.1706 (0.42)       1387           1
test_lz4[html-python-lz4]                             696.9610 (3.38)      1,266.9380 (3.01)        769.8121 (3.27)        89.4869 (3.06)        740.7540 (3.39)        54.1665 (2.82)        94;98  1,299.0183 (0.31)       1085           1
test_lz4[html_x_4-cramjam]                          2,149.2940 (10.44)     4,065.1930 (9.65)      2,412.1607 (10.26)      305.1893 (10.43)     2,325.4890 (10.64)      184.0815 (9.57)        38;39    414.5661 (0.10)        348           1
test_lz4[html_x_4-python-lz4]                       2,932.0430 (14.24)     3,806.8100 (9.04)      3,143.4955 (13.37)      165.2213 (5.65)      3,102.5030 (14.19)      111.0107 (5.77)        40;22    318.1172 (0.07)        231           1
test_lz4[kppkn.gtb-cramjam]                         1,679.8610 (8.16)      2,542.5370 (6.04)      1,789.8313 (7.61)       106.6801 (3.65)      1,768.8005 (8.09)        87.1930 (4.53)        59;27    558.7119 (0.13)        462           1
test_lz4[kppkn.gtb-python-lz4]                      3,209.9940 (15.59)     4,404.1140 (10.46)     3,393.7427 (14.44)      157.5778 (5.39)      3,351.8800 (15.33)      150.1042 (7.81)        31;12    294.6599 (0.07)        275           1
test_lz4[lcet10.txt-cramjam]                        4,852.5360 (23.57)     7,953.2970 (18.89)     5,275.6863 (22.44)      474.4112 (16.22)     5,182.7910 (23.71)      278.4967 (14.48)         9;9    189.5488 (0.04)        199           1
test_lz4[lcet10.txt-python-lz4]                     8,251.3110 (40.07)    12,421.4480 (29.49)     8,792.2057 (37.40)      554.4787 (18.95)     8,662.1010 (39.62)      373.2330 (19.41)         7;7    113.7371 (0.03)        114           1
test_lz4[paper-100k.pdf-cramjam]                      405.3170 (1.97)        673.3370 (1.60)        429.1101 (1.83)        34.4027 (1.18)        419.5350 (1.92)        25.4660 (1.32)      165;148  2,330.4041 (0.55)       2110           1
test_lz4[paper-100k.pdf-python-lz4]                 1,752.0420 (8.51)      2,357.7380 (5.60)      1,847.5694 (7.86)        86.1250 (2.94)      1,821.4480 (8.33)        86.6703 (4.51)       125;34    541.2517 (0.13)        517           1
test_lz4[plrabn12.txt-cramjam]                      5,994.5400 (29.11)    10,160.5840 (24.13)     6,528.1635 (27.77)      479.6425 (16.40)     6,415.1230 (29.34)      244.5412 (12.72)       11;11    153.1824 (0.04)        127           1
test_lz4[plrabn12.txt-python-lz4]                  11,911.5420 (57.85)    19,488.4880 (46.28)    13,580.5948 (57.76)    1,975.2401 (67.52)    12,662.1220 (57.92)    1,491.3778 (77.55)       13;13     73.6345 (0.02)         81           1
test_lz4[urls.10K-cramjam]                          6,125.3900 (29.75)    10,022.6590 (23.80)     6,906.8542 (29.38)      800.5537 (27.37)     6,660.1280 (30.46)      327.7380 (17.04)       15;16    144.7837 (0.03)        153           1
test_lz4[urls.10K-python-lz4]                       9,350.5950 (45.41)    13,417.3250 (31.86)    10,231.2214 (43.52)      722.7599 (24.71)    10,112.5745 (46.26)      622.8635 (32.39)        11;8     97.7400 (0.02)         96           1
---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
```

#### Brotli

`make bench-brotli`

```bash
----------------------------------------------------------------------------------------------------- benchmark: 24 tests ------------------------------------------------------------------------------------------------------
Name (time in ms)                                         Min                   Max                  Mean             StdDev                Median                IQR            Outliers      OPS            Rounds  Iterations
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_brotli[Mark.Twain-Tom.Sawyer.txt-brotli]         18.2539 (1.0)         22.8656 (1.14)        18.9863 (1.0)       0.7931 (1.94)        18.8713 (1.0)       0.3620 (1.0)           3;3  52.6695 (1.0)          51           1
test_brotli[Mark.Twain-Tom.Sawyer.txt-cramjam]        18.4573 (1.01)        19.9932 (1.0)         19.0165 (1.00)      0.4094 (1.0)         18.9207 (1.00)      0.5462 (1.51)         18;0  52.5860 (1.00)         51           1
test_brotli[alice29.txt-brotli]                      225.5098 (12.35)      233.2325 (11.67)      227.9498 (12.01)     3.2069 (7.83)       226.3776 (12.00)     4.0514 (11.19)         1;0   4.3869 (0.08)          5           1
test_brotli[alice29.txt-cramjam]                     233.5171 (12.79)      235.4350 (11.78)      234.6430 (12.36)     0.7237 (1.77)       234.8783 (12.45)     0.8757 (2.42)          2;0   4.2618 (0.08)          5           1
test_brotli[asyoulik.txt-brotli]                     187.4845 (10.27)      197.4504 (9.88)       193.1492 (10.17)     3.7175 (9.08)       194.0205 (10.28)     4.5618 (12.60)         2;0   5.1773 (0.10)          5           1
test_brotli[asyoulik.txt-cramjam]                    185.8101 (10.18)      192.5796 (9.63)       189.0552 (9.96)      2.4759 (6.05)       189.2976 (10.03)     3.5369 (9.77)          2;0   5.2895 (0.10)          6           1
test_brotli[fireworks.jpeg-brotli]                    74.7665 (4.10)       107.0830 (5.36)        82.2891 (4.33)      8.4381 (20.61)       80.2819 (4.25)      8.3648 (23.11)         1;1  12.1523 (0.23)         13           1
test_brotli[fireworks.jpeg-cramjam]                   74.2872 (4.07)        80.4223 (4.02)        76.5993 (4.03)      2.0518 (5.01)        75.4147 (4.00)      3.2772 (9.05)          4;0  13.0549 (0.25)         13           1
test_brotli[geo.protodata-brotli]                    128.6399 (7.05)       130.4648 (6.53)       129.3095 (6.81)      0.6225 (1.52)       129.3085 (6.85)      0.8858 (2.45)          2;0   7.7334 (0.15)          8           1
test_brotli[geo.protodata-cramjam]                   132.1978 (7.24)       135.9461 (6.80)       133.4739 (7.03)      1.3324 (3.25)       132.8753 (7.04)      1.8923 (5.23)          2;0   7.4921 (0.14)          8           1
test_brotli[html-brotli]                             134.8012 (7.38)       145.0839 (7.26)       136.9357 (7.21)      3.3821 (8.26)       135.6421 (7.19)      1.6070 (4.44)          1;1   7.3027 (0.14)          8           1
test_brotli[html-cramjam]                            138.4083 (7.58)       142.2173 (7.11)       139.8572 (7.37)      1.4800 (3.62)       139.2130 (7.38)      2.5172 (6.95)          2;0   7.1501 (0.14)          8           1
test_brotli[html_x_4-brotli]                         171.6389 (9.40)       180.3112 (9.02)       176.3479 (9.29)      3.4427 (8.41)       176.0761 (9.33)      6.0443 (16.70)         3;0   5.6706 (0.11)          6           1
test_brotli[html_x_4-cramjam]                        180.0620 (9.86)       196.8542 (9.85)       188.7382 (9.94)      7.2089 (17.61)      189.4560 (10.04)    15.2504 (42.13)         3;0   5.2983 (0.10)          6           1
test_brotli[kppkn.gtb-brotli]                        447.6251 (24.52)      475.9302 (23.80)      463.3429 (24.40)    10.8179 (26.43)      464.2027 (24.60)    15.2439 (42.12)         2;0   2.1582 (0.04)          5           1
test_brotli[kppkn.gtb-cramjam]                       446.2874 (24.45)      456.8182 (22.85)      450.9967 (23.75)     4.4023 (10.75)      452.4705 (23.98)     6.8669 (18.97)         2;0   2.2173 (0.04)          5           1
test_brotli[lcet10.txt-brotli]                       714.6673 (39.15)      734.2637 (36.73)      723.5614 (38.11)     8.6142 (21.04)      720.8160 (38.20)    15.2477 (42.13)         2;0   1.3821 (0.03)          5           1
test_brotli[lcet10.txt-cramjam]                      736.3283 (40.34)      811.1870 (40.57)      764.1775 (40.25)    30.8189 (75.28)      754.4741 (39.98)    46.2688 (127.83)        1;0   1.3086 (0.02)          5           1
test_brotli[paper-100k.pdf-brotli]                   406.3972 (22.26)      408.4076 (20.43)      407.4876 (21.46)     0.8200 (2.00)       407.7548 (21.61)     1.3093 (3.62)          2;0   2.4541 (0.05)          5           1
test_brotli[paper-100k.pdf-cramjam]                  409.8010 (22.45)      434.1073 (21.71)      421.4300 (22.20)     9.7730 (23.87)      417.9097 (22.15)    14.9918 (41.42)         2;0   2.3729 (0.05)          5           1
test_brotli[plrabn12.txt-brotli]                     794.1873 (43.51)      819.0397 (40.97)      806.7543 (42.49)    10.6155 (25.93)      803.9709 (42.60)    18.2808 (50.51)         2;0   1.2395 (0.02)          5           1
test_brotli[plrabn12.txt-cramjam]                    802.7903 (43.98)      818.8850 (40.96)      811.7899 (42.76)     7.6594 (18.71)      814.7583 (43.17)    14.3045 (39.52)         1;0   1.2318 (0.02)          5           1
test_brotli[urls.10K-brotli]                       1,282.8863 (70.28)    1,329.7179 (66.51)    1,303.8467 (68.67)    19.9188 (48.66)    1,294.4292 (68.59)    32.3713 (89.43)         2;0   0.7670 (0.01)          5           1
test_brotli[urls.10K-cramjam]                      1,300.4646 (71.24)    1,344.7246 (67.26)    1,317.4961 (69.39)    20.5248 (50.14)    1,305.3920 (69.17)    34.9071 (96.44)         1;0   0.7590 (0.01)          5           1
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
```

#### ZSTD

`make bench-zstd`

```bash 
------------------------------------------------------------------------------------------------------- benchmark: 24 tests -------------------------------------------------------------------------------------------------------
Name (time in us)                                       Min                   Max                  Mean              StdDev                Median                 IQR            Outliers         OPS            Rounds  Iterations
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
test_zstd[Mark.Twain-Tom.Sawyer.txt-cramjam]       154.4260 (1.0)        429.8220 (1.61)       165.7084 (1.0)       18.0132 (1.0)        159.4600 (1.0)       11.8590 (1.0)       211;207  6,034.6953 (1.0)        1685           1
test_zstd[Mark.Twain-Tom.Sawyer.txt-zstd]          191.9860 (1.24)       267.6270 (1.0)        219.1654 (1.32)      28.9777 (1.61)       197.9910 (1.24)      56.6957 (4.78)         22;0  4,562.7633 (0.76)         53           1
test_zstd[alice29.txt-cramjam]                   1,362.2300 (8.82)     2,102.8580 (7.86)     1,439.4675 (8.69)      73.2922 (4.07)     1,422.7575 (8.92)      70.1800 (5.92)       134;36    694.7014 (0.12)        684           1
test_zstd[alice29.txt-zstd]                      1,315.1700 (8.52)     2,365.9580 (8.84)     1,403.9396 (8.47)     120.7466 (6.70)     1,372.8835 (8.61)      70.7280 (5.96)        72;76    712.2813 (0.12)        744           1
test_zstd[asyoulik.txt-cramjam]                  1,211.2850 (7.84)     1,841.2200 (6.88)     1,284.1431 (7.75)      77.5367 (4.30)     1,270.1210 (7.97)      59.2710 (5.00)        78;53    778.7294 (0.13)        757           1
test_zstd[asyoulik.txt-zstd]                     1,157.6700 (7.50)     1,653.1200 (6.18)     1,220.0159 (7.36)      65.1603 (3.62)     1,204.0080 (7.55)      55.9547 (4.72)        92;49    819.6615 (0.14)        805           1
test_zstd[fireworks.jpeg-cramjam]                  292.3470 (1.89)       602.9980 (2.25)       313.0014 (1.89)      33.5971 (1.87)       302.4510 (1.90)      20.7312 (1.75)      287;295  3,194.8734 (0.53)       3057           1
test_zstd[fireworks.jpeg-zstd]                     216.5420 (1.40)       452.4620 (1.69)       229.1745 (1.38)      22.7349 (1.26)       222.9190 (1.40)      12.9210 (1.09)      378;420  4,363.4868 (0.72)       3623           1
test_zstd[geo.protodata-cramjam]                   324.0560 (2.10)       672.1640 (2.51)       354.0909 (2.14)      42.7156 (2.37)       340.2680 (2.13)      27.8100 (2.35)      216;209  2,824.1338 (0.47)       2621           1
test_zstd[geo.protodata-zstd]                      281.7450 (1.82)       535.1640 (2.00)       300.6179 (1.81)      29.3579 (1.63)       291.3200 (1.83)      18.6490 (1.57)      247;242  3,326.4816 (0.55)       2894           1
test_zstd[html-cramjam]                            349.8810 (2.27)       769.5230 (2.88)       376.6673 (2.27)      43.1311 (2.39)       362.2320 (2.27)      27.6060 (2.33)      188;186  2,654.8631 (0.44)       2332           1
test_zstd[html-zstd]                               312.4120 (2.02)       580.8570 (2.17)       333.4397 (2.01)      32.0637 (1.78)       323.5910 (2.03)      21.6778 (1.83)      253;222  2,999.0433 (0.50)       2851           1
test_zstd[html_x_4-cramjam]                        476.8870 (3.09)       887.5280 (3.32)       537.3586 (3.24)      76.9432 (4.27)       509.1320 (3.19)      46.7175 (3.94)      115;122  1,860.9548 (0.31)        909           1
test_zstd[html_x_4-zstd]                           364.0010 (2.36)       797.9640 (2.98)       389.8506 (2.35)      37.9180 (2.11)       377.5145 (2.37)      28.5240 (2.41)      215;177  2,565.0855 (0.43)       2332           1
test_zstd[kppkn.gtb-cramjam]                     1,082.0570 (7.01)     1,696.9090 (6.34)     1,148.6073 (6.93)      72.4650 (4.02)     1,131.7090 (7.10)      57.8217 (4.88)        85;62    870.6196 (0.14)        749           1
test_zstd[kppkn.gtb-zstd]                        1,043.9460 (6.76)     1,771.5120 (6.62)     1,110.4534 (6.70)      81.5983 (4.53)     1,090.0220 (6.84)      54.9060 (4.63)        95;82    900.5331 (0.15)        879           1
test_zstd[lcet10.txt-cramjam]                    3,509.2670 (22.72)    5,409.0240 (20.21)    3,734.3465 (22.54)    230.2715 (12.78)    3,684.9145 (23.11)    163.8595 (13.82)       19;14    267.7845 (0.04)        268           1
test_zstd[lcet10.txt-zstd]                       3,387.3740 (21.94)    5,608.0490 (20.95)    3,595.1312 (21.70)    246.2549 (13.67)    3,542.5960 (22.22)    180.9382 (15.26)       19;12    278.1540 (0.05)        283           1
test_zstd[paper-100k.pdf-cramjam]                  488.0500 (3.16)       942.0480 (3.52)       520.3597 (3.14)      44.4527 (2.47)       508.0725 (3.19)      36.1535 (3.05)      166;116  1,921.7476 (0.32)       1900           1
test_zstd[paper-100k.pdf-zstd]                     479.8510 (3.11)       868.9010 (3.25)       520.1514 (3.14)      46.2761 (2.57)       509.5520 (3.20)      28.6118 (2.41)      197;190  1,922.5171 (0.32)       1977           1
test_zstd[plrabn12.txt-cramjam]                  4,742.2590 (30.71)    6,472.1400 (24.18)    5,019.8933 (30.29)    234.2066 (13.00)    4,958.0030 (31.09)    198.3953 (16.73)       26;12    199.2074 (0.03)        167           1
test_zstd[plrabn12.txt-zstd]                     4,586.0060 (29.70)    6,362.5020 (23.77)    4,846.4730 (29.25)    238.6297 (13.25)    4,803.3360 (30.12)    206.9840 (17.45)        26;9    206.3356 (0.03)        203           1
test_zstd[urls.10K-cramjam]                      4,455.0140 (28.85)    8,134.9550 (30.40)    4,870.4095 (29.39)    491.9910 (27.31)    4,727.1960 (29.65)    212.0393 (17.88)       23;28    205.3215 (0.03)        201           1
test_zstd[urls.10K-zstd]                         4,177.0250 (27.05)    5,455.3670 (20.38)    4,437.3242 (26.78)    210.9385 (11.71)    4,382.1610 (27.48)    231.2377 (19.50)       44;11    225.3610 (0.04)        227           1
-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
```




